@@ -21,12 +21,14 @@ def get_section_regex(tg, beg_section_name, end_section_name):
                 return r'(?<='+beg_section_name+r')[\S\s\t\n]+?(?=[\S\s\t\n]{,5}'+end_section_name+')'
         if tg=='': #done
                 return r'(?<=[\S]{1,2}'+beg_section_name+r')[\S\s\t\n]+?(?=[\S]{1,2}'+end_section_name+')'
-        if tg=='' or tg=='': #done
+        if tg=='': #done
                 return r'(?<=--	'+beg_section_name+r')[\S\s\n\t]+?(?=--	'+end_section_name+')'
         if tg=='ͨ': #done
                 return r'(?<=--		'+beg_section_name+r')[\S\s\n\t]+?(?=--		'+end_section_name+')'
         if tg=='ҵ': #done
                 return r'(?<=--(\t| )'+beg_section_name+r')[\S\s\n\t]+?(?=--(\t|	)'+end_section_name+')'
+        if tg=='':
+                return r'((?<=--		'+beg_section_name+r')[\S\s\n\t]+?(?=--		'+end_section_name+')'+r'|(?<='+beg_section_name+r')[\S\s\t\n]+?(?=[\S\s\t\n]{,5}'+end_section_name+'))'
 
 def get_section_beg_end(tg, req_section):
         sections_dict = {'̩':['ͶĿ','ͶʷΧ','Ͷʲ','ҵȽϻ׼','Ͷ','ͶʽֹΪ'],
